@@ -120,7 +120,6 @@ class NodeBase(object):
 
         self._stale = True
         self._frozen = False
-        self._callbacks = []
         self._children = []
         self._parents = set()
 
@@ -168,16 +167,6 @@ class NodeBase(object):
             raise NodeException("Invalid node name '%s'. Must be Python identifier!"
                                 % (name,))
 
-    def _execute_callbacks(self):
-        """
-        Execute callbacks upon notifying parents.
-        """
-        for _cb in self._callbacks:
-            _cb['func'](
-                *(_cb['args'] or []),
-                **(_cb['kwargs'] or {})
-            )
-
     # -- properties
 
     @property
@@ -249,7 +238,7 @@ class NodeBase(object):
         :return: a list containing the children of this node.
         :rtype: list of NodeBase
         """
-        return list(self.iter_children())
+        return self._children
 
     def get_parents(self):
         """
@@ -302,13 +291,6 @@ class NodeBase(object):
 
         # do *not* remove self node from node children
 
-    def iter_children(self):
-        """
-        Generator for child nodes.
-        """
-        for _child in self._children:
-            yield _child
-
     def iter_parents(self):
         """
         Generator for parent nodes.
@@ -361,13 +343,6 @@ class NodeBase(object):
         """
         Notify parents that they will need to be updated because this node has changed.
         """
-        # frozen nodes do not notify their parents
-        if self.frozen:
-            return
-
-        # execute any callback functions
-        self._execute_callbacks()
-
         for _p in self.iter_parents():
             _p.mark_for_update()
 
@@ -382,13 +357,15 @@ class NodeBase(object):
         Sets this node's frozen property to False.
         """
         self._frozen = False
+        self._stale = True
 
     def mark_for_update(self):
         """
         Sets this node's stale property to True.
         """
-        self._stale = True
-        self.notify_parents()
+        if not self.stale and not self.frozen:
+            self._stale = True
+            self.notify_parents()
 
     def update(self):
         """
@@ -437,18 +414,7 @@ class NodeBase(object):
         self._children = [_c if _c is not current_child else new_child for _c in self._children]
         new_child.add_parent(self)
         current_child.remove_parent(self)
-
-    def register_callback(self, func, args=None, kwargs=None):
-        """
-        Add a function to be called when this node notifies its parents.
-        :param func: the function to be called.
-        :type func: Callable
-        :param args: the args to call the function with.
-        :type args: list
-        :param kwargs: the kwargs to call the function with.
-        :type kwargs: dict
-        """
-        self._callbacks.append(dict(func=func, args=args, kwargs=kwargs))
+        self.mark_for_update()
 
     def print_descendants(self):
         """
@@ -466,7 +432,6 @@ class RootNode(NodeBase):
     def __init__(self):
         self._name = '__root__'
         self._stale = True
-        self._callbacks = []
         self._children = []
         self._parents = set()  # root node has no parents
 
@@ -685,6 +650,7 @@ class Alias(ValueNode):
 
     def update(self):
         self._value = self.ref.value
+        self._stale = False
 
 
 class Function(ValueNode):
@@ -756,6 +722,9 @@ class Function(ValueNode):
         self.add_child(parameter)
 
     def update(self):
+        for _child in self.get_children():
+            if _child.stale and not _child.frozen:
+                _child.update()
         self._par_cache = [
             _par.value
             for _par in self._parameters
@@ -874,18 +843,12 @@ class Tuple(ValueNode):
     def nodes(self, nodes):
         self.set_children(nodes)
 
-    def _update(self):
+    def update(self):
         self._value = tuple([
             _node.value for _node in self.nodes
         ])
         self._stale = False
 
-    @property
-    def value(self):
-        if self.stale:
-            self._update()
-        return self._value
-
     def iter_values(self):
         """
         Generator for Tuple.value.
@@ -921,7 +884,7 @@ class Array(Tuple):
         self.set_children(nodes)
         self._value = np.empty(len(nodes), dtype=self._dtype)
 
-    def _update(self):
+    def update(self):
         for _i, _node in enumerate(self.nodes):
             self._value[_i] = _node.value
 
@@ -953,7 +916,7 @@ class NodeChildrenPrinter(object):
         self.visit(node, indent=indent)
 
         # recursively visit children
-        for _c in node.iter_children():
+        for _c in node.get_children():
             self.run(_c, indent=indent + '  ')
 
 
@@ -984,7 +947,7 @@ class NodeSubgraphGraphvizSourceProducer(object):
 
     def visit(self, node):
         self._nodes.add(node)
-        for _c in node.iter_children():
+        for _c in node.get_children():
             self._nodes.add(node)
             if node in self._exclude or _c in self._exclude:
                 continue
@@ -1017,7 +980,7 @@ class NodeSubgraphGraphvizSourceProducer(object):
         node_chain.add(node)
 
         # recursively visit children
-        for _c in node.iter_children():
+        for _c in node.get_children():
             NodeSubgraphGraphvizSourceProducer.run(self, _c, node_chain=node_chain)
         # recursively visit parents
         for _p in node.iter_parents():
@@ -1116,8 +1079,8 @@ class NodeCycleChecker(object):
         # keep track of nodes encountered
         seen += (node,)
 
-        # recursively visit children
-        for _c in node.iter_children():
+        # recursively visit parents
+        for _c in node.iter_parents():
             self.run(node=_c, seen=seen)
 
 
@@ -1213,7 +1176,7 @@ class Nexus(object):
             if existing_behavior == 'replace':
                 if add_children:
                     # add all dependent children to the nexus first
-                    for _child in node.iter_children():
+                    for _child in node.get_children():
                         self.add(_child, add_children=True, existing_behavior='ignore')
                 # replace node
                 self._nodes[node.name].replace(node)
@@ -1226,14 +1189,14 @@ class Nexus(object):
         else:
             if add_children:
                 # add all dependent children to the nexus first
-                for _child in node.iter_children():
+                for _child in node.get_children():
                     self.add(_child, add_children=True, existing_behavior='ignore')
 
             # add new node as child of root node
             self._root_ref().add_child(node)
 
             # remove nexus root from all children's parents (if present)
-            for _child in node.iter_children():
+            for _child in node.get_children():
                 try:
                     self._root_ref().remove_child(_child)
                 except KeyError:
@@ -1243,7 +1206,7 @@ class Nexus(object):
         self._nodes[node.name] = node
 
         # check for cycles
-        NodeCycleChecker(self._root_ref()).run()
+        NodeCycleChecker(node).run()
 
         return node
 
@@ -1498,7 +1461,7 @@ class Nexus(object):
             _node.add_child(self.get(_dep))
 
         # check for cycles
-        NodeCycleChecker(self._root_ref()).run()
+        NodeCycleChecker(_node).run()
 
     def get(self, node_name):
         """Retrieve a node by its name or ``None`` if no such node exists.
