@@ -1,7 +1,7 @@
-import abc
 import sys
-import six
+import warnings
 
+from .minimizer_base import MinimizerException
 from ...config import kc
 
 __all__ = ['get_minimizer']
@@ -35,6 +35,8 @@ except _catch_error_class:
     pass
 except SyntaxError:  # Newer versions of iminuit do not support Python 2.
     pass
+except MinimizerException as e:  # kafe2 does not support iminuit>2
+    warnings.warn("Problem importing iminuit: {}\nIminuit won't be available".format(e))
 
 try:
     from .root_tminuit_minimizer import MinimizerROOTTMinuit
@@ -53,7 +55,14 @@ if not AVAILABLE_MINIMIZERS:
                        "at least one of the following Python packages is installed: "
                        "['scipy', 'iminuit', 'ROOT']")
 
+
 def get_minimizer(minimizer_spec=None):
+    """Creates a MinimizerBase object from a given minimizer name.
+
+    :param minimizer_spec: Name of the minimizer to return.
+    :type minimizer_spec: str or None
+    :return: MinimizerBase-derived kafe2 minimizer object
+    """
     global AVAILABLE_MINIMIZERS
     # for 'None', return the default minimizer
     if minimizer_spec is None:
@@ -69,38 +78,13 @@ def get_minimizer(minimizer_spec=None):
                 return _minimizer
 
         raise ValueError(
-            "Could not find any minimizer in default list: {}! Available: {}".format(_minimizer_specs,
-                                                                                     list(AVAILABLE_MINIMIZERS.keys())))
+            "Could not find any minimizer in default list: {}! "
+            "Available: {}".format(_minimizer_specs, list(AVAILABLE_MINIMIZERS.keys())))
     _minimizer_spec = minimizer_spec.lower()
     _minimizer_spec = _MINIMIZER_NAME_ALIASES.get(_minimizer_spec, _minimizer_spec)
     _minimizer = AVAILABLE_MINIMIZERS.get(_minimizer_spec, None)
     if _minimizer is not None:
         return _minimizer
 
-    raise ValueError("Unknown minimizer '{}'! Available: {}".format(minimizer_spec, list(AVAILABLE_MINIMIZERS.keys())))
-
-
-@six.add_metaclass(abc.ABCMeta)
-class MinimizerBase(object):
-    """
-    Purely abstract class. Defines the minimal interface required by all specializations.
-    """
-
-    @abc.abstractmethod
-    def minimize(self):
-        pass
-
-    @property
-    @abc.abstractmethod
-    def hessian(self):
-        pass
-
-    @property
-    @abc.abstractmethod
-    def hessian_inv(self):
-        pass
-
-    @property
-    @abc.abstractmethod
-    def function_value(self):
-        pass
+    raise ValueError("Unknown minimizer '{}'! "
+                     "Available: {}".format(minimizer_spec, list(AVAILABLE_MINIMIZERS.keys())))
