@@ -10,13 +10,13 @@ import six
 from .container import DataContainerBase, DataContainerException
 from ..io.file import FileIOMixin
 from ...config import kc
-from ...core.fitters.nexus import Nexus, NexusError, Parameter
+from ...core.fitters.nexus import Nexus, NexusError, Parameter, Array
 from ...core.fitters.nexus_fitter import NexusFitter
 from ...core.constraint import GaussianMatrixParameterConstraint, GaussianSimpleParameterConstraint
 from ...core.error import CovMat
 from ...tools import print_dict_as_table
 from .._base.cost import CostFunction, STRING_TO_COST_FUNCTION
-from ..util import invert_matrix, add_in_quadrature
+from ..util import invert_matrix, add_in_quadrature, cholesky_decomposition, log_determinant
 
 __all__ = ["FitBase", "FitException"]
 
@@ -146,18 +146,18 @@ class FitBase(FileIOMixin, object):
 
         # -- fit parameters
 
+        _parameter_nodes = []
         # get names and default values of all parameters if the fit has a model function
         if self._model_function is not None:
             for _par_name, _par_value in six.iteritems(self._model_function.defaults_dict):
                 # create nexus node for function parameter
-                self._nexus.add(Parameter(_par_value, name=_par_name))
+                _parameter_nodes.append(self._nexus.add(Parameter(_par_value, name=_par_name)))
 
                 self._fit_param_names.append(_par_name)
 
-        self._nexus.add_function(lambda: self.parameter_values, func_name='parameter_values')
+        self._nexus.add(Array(_parameter_nodes, name="parameter_values"))
         self._nexus.add_function(lambda: self.parameter_constraints,
                                  func_name='parameter_constraints')
-        self._nexus.add_dependency('parameter_values', depends_on=self._fit_param_names)
 
         # -- errors
 
@@ -171,18 +171,27 @@ class FitBase(FileIOMixin, object):
                 _mat_name = '_'.join((_axis, _type, "cov_mat")) if _axis is not None \
                     else '_'.join((_type, "cov_mat"))
                 if _type == "total":
-                    self._add_property_to_nexus(_error_name, depends_on=_error_names)
-                    self._add_property_to_nexus(_mat_name, depends_on=_mat_names)
+                    # Performance optimization: calculate total foo in Nexus
+                    self._nexus.add_function(
+                        lambda m, d: np.sqrt(m ** 2 + d ** 2),
+                        func_name=_error_name, par_names=_error_names)
+                    self._nexus.add_function(
+                        lambda m, d: m + d, func_name=_mat_name, par_names=_mat_names)
                 else:
                     self._add_property_to_nexus(_name)
                     self._add_property_to_nexus(_error_name)
                     _error_names.append(_error_name)
                     self._add_property_to_nexus(_mat_name)
                     _mat_names.append(_mat_name)
-                if _type == "model":
+                if _error_name in self._MODEL_ERROR_NODE_NAMES:
                     self._nexus.add_dependency(_error_name, depends_on="parameter_values")
+                if _mat_name in self._MODEL_ERROR_NODE_NAMES:
                     self._nexus.add_dependency(_mat_name, depends_on="parameter_values")
                 self._add_property_to_nexus(_mat_name + "_inverse", depends_on=_mat_name)
+                self._nexus.add_function(cholesky_decomposition, func_name=_mat_name + "_cholesky",
+                                         par_names=[_mat_name])
+                self._nexus.add_function(log_determinant, func_name=_mat_name + "_log_determinant",
+                                         par_names=[_mat_name + "_cholesky"])
 
         if self._model_function is not None:
             # add the original function name as an alias to 'model'
@@ -307,22 +316,19 @@ class FitBase(FileIOMixin, object):
 
         _pf = self._cost_function.formatter
         output_stream.write(
-            indent * (indentation_level + 2) + "cost function: {}\n\n".format(_pf.description))
-        if self._cost_function.saturated:
-            _gof_string = "cost / ndf = "
-            _gof_value = self.cost_function_value
-        else:
-            output_stream.write(indent * (indentation_level + 2) + "cost = ")
+            indent * (indentation_level + 2) + "Cost function: {}\n\n".format(_pf.description))
+        _gof_value = self.goodness_of_fit
+        output_stream.write(indent * (indentation_level + 2))
+        if _gof_value is None:
+            output_stream.write("Cost = ")
             output_stream.write(_pf.get_formatted(
                 value=self.cost_function_value,
                 with_name=False,
-                format_as_latex=False,
+                format_as_latex=False
             ))
-            output_stream.write('\n\n')
-            _gof_string = "GoF / ndf = "
-            _gof_value = self.goodness_of_fit
-        if _gof_value is not None:
-            output_stream.write(indent * (indentation_level + 2) + _gof_string)
+        else:
+            _gof_string = "chi2 / ndf = " if self._cost_function.is_chi2 else "GoF / ndf = "
+            output_stream.write(_gof_string)
             output_stream.write(_pf.get_formatted(
                 value=_gof_value,
                 n_degrees_of_freedom=self.ndf,
@@ -330,7 +336,7 @@ class FitBase(FileIOMixin, object):
                 with_value_per_ndf=True,
                 format_as_latex=False
             ))
-            output_stream.write('\n\n')
+        output_stream.write('\n\n')
         _chi2_prob = self.chi2_probability
         if _chi2_prob is not None:
             output_stream.write("%schi2 probability = %#.3g\n\n" % (
@@ -473,12 +479,12 @@ class FitBase(FileIOMixin, object):
     @property
     def total_error(self):
         """array of pointwise total uncertainties"""
-        return add_in_quadrature(self.data_error, self.model_error)
+        return self._nexus.get("total_error").value
 
     @property
     def total_cov_mat(self):
         """the total covariance matrix"""
-        return self.data_cov_mat + self.model_cov_mat
+        return self._nexus.get("total_cov_mat").value
 
     @property
     def total_cov_mat_inverse(self):
@@ -516,9 +522,7 @@ class FitBase(FileIOMixin, object):
 
         :rtype: numpy.ndarray[float]
         """
-        _par_val_dict = self.parameter_name_value_dict
-        _par_names = self.parameter_names
-        return np.array([_par_val_dict[_par_name] for _par_name in _par_names])
+        return self._nexus.get("parameter_values").value
 
     @property
     def parameter_names(self):
@@ -650,7 +654,10 @@ class FitBase(FileIOMixin, object):
 
         :rtype: int
         """
-        return self._param_model.ndf + len(self._fitter.fixed_parameters)
+        _extra_ndf_constraints = 0
+        for _parameter_constraint in self._fit_param_constraints:
+            _extra_ndf_constraints += _parameter_constraint.extra_ndf
+        return self._param_model.ndf + len(self._fitter.fixed_parameters) + _extra_ndf_constraints
 
     @property
     def goodness_of_fit(self):
@@ -676,7 +683,10 @@ class FitBase(FileIOMixin, object):
     @property
     def chi2_probability(self):
         """The chi2 probability for the current model values."""
-        return self._cost_function.chi2_probability(self.cost_function_value, self.ndf)
+        _cost = self.cost_function_value
+        if self._cost_function.add_determinant_cost:
+            _cost -= self._nexus.get("total_cov_mat_log_determinant").value
+        return self._cost_function.chi2_probability(_cost, self.ndf)
 
     # -- public methods
 
@@ -685,13 +695,16 @@ class FitBase(FileIOMixin, object):
 
         :param param_name_value_dict: new parameter values
         """
-        return self._fitter.set_fit_parameter_values(**param_name_value_dict)
+        _return_value = self._fitter.set_fit_parameter_values(**param_name_value_dict)
+        self._param_model.parameters = self.parameter_values
+        return _return_value
 
     def set_all_parameter_values(self, param_value_list):
         """Set all the fit parameters at the same time.
 
         :param typing.Iterable[float] param_value_list: List of parameter values (mind the order).
         """
+        self._param_model.parameters = param_value_list
         return self._fitter.set_all_fit_parameter_values(param_value_list)
 
     def fix_parameter(self, name, value=None):
@@ -1058,8 +1071,9 @@ class FitBase(FileIOMixin, object):
         _ndf = self.ndf
         _result_dict['cost'] = _cost
         _result_dict['ndf'] = _ndf
-        _result_dict['goodness_of_fit'] = self.goodness_of_fit
-        _result_dict['cost/ndf'] = _cost / _ndf
+        _gof = self.goodness_of_fit
+        _result_dict['goodness_of_fit'] = _gof
+        _result_dict['gof/ndf'] = _gof / _ndf if _gof is not None else _gof
         _result_dict['chi2_probability'] = self.chi2_probability
         _result_dict['parameter_values'] = self.parameter_name_value_dict
         if _result_dict['did_fit']:
