@@ -1,4 +1,3 @@
-from funcsigs import Signature, Parameter
 import numpy as np
 
 from .._base import CostFunction, CostFunction_Chi2
@@ -10,10 +9,10 @@ class SharedCostFunction(CostFunction_Chi2):
     def __init__(self, fallback_on_singular=True):
         self._DATA_NAME = "y_data"
         self._MODEL_NAME = "y_model"
-        self._COV_MAT_INVERSE_NAME = "total_cov_mat_inverse"
+        self._COV_MAT_CHOLESKY_NAME = "total_cov_mat_cholesky"
         super(SharedCostFunction, self).__init__(
             errors_to_use="covariance", fallback_on_singular=fallback_on_singular,
-            add_constraint_cost=False)
+            add_constraint_cost=False, add_determinant_cost=True)
 
 
 class MultiCostFunction(CostFunction):
@@ -22,7 +21,8 @@ class MultiCostFunction(CostFunction):
         super(MultiCostFunction, self).__init__(
             cost_function=MultiCostFunction.cost_sum,
             arg_names=cost_function_names,
-            add_constraint_cost=True
+            add_constraint_cost=True,
+            add_determinant_cost=False
         )
         self._needs_errors = np.any([_scf.needs_errors for _scf in singular_cost_functions])
         self._saturated = np.all([_scf.saturated for _scf in singular_cost_functions])
