@@ -7,10 +7,11 @@ import numpy as np
 
 from .cost import SharedCostFunction, MultiCostFunction
 from .._base import FitBase
-from ...core import NexusFitter
-from ...core.error import SimpleGaussianError, MatrixGaussianError
+from ...core.fitters import NexusFitter
+from ...core.error import SimpleGaussianError, MatrixGaussianError, CovMat
 from ...core.fitters.nexus import Alias, Function, Array, Parameter
 from ...tools import random_alphanumeric
+from ..util import cholesky_decomposition, log_determinant, invert_matrix
 
 __all__ = ['MultiFit']
 
@@ -80,6 +81,8 @@ class MultiFit(FitBase):
         return [self.parameter_names.index(_parameter_name) for _parameter_name in singular_fit.parameter_names]
 
     def _update_parameter_formatters(self, update_asymmetric_errors=False):
+        if update_asymmetric_errors:
+            _ = self.asymmetric_parameter_errors  # Ensure asymm par errs are calculated.
         for _fit in self._fits:
             _fit._update_parameter_formatters(update_asymmetric_errors=update_asymmetric_errors)
 
@@ -126,7 +129,7 @@ class MultiFit(FitBase):
             existing_behavior="replace"
         )
 
-        self._y_data_names = []
+        _log_det_names = []
         for _i, _fit_i in enumerate(self._fits):
             _fit_i._initialize_fitter()
 
@@ -143,7 +146,19 @@ class MultiFit(FitBase):
                 self._nexus.add(
                     Alias(ref=_y_data_node, name=_y_data_name),
                     add_children=False)
-                self._y_data_names.append(_y_data_name)
+
+            _log_det_node = _fit_i._nexus.get('total_cov_mat_log_determinant')
+            if _log_det_node is not None:
+                _log_det_name = 'total_cov_mat_log_determinant%s' % _i
+                self._nexus.add(
+                    Alias(ref=_log_det_node, name=_log_det_name),
+                    add_children=False)
+                _log_det_names.append(_log_det_name)
+
+        self._nexus.add_function(
+            lambda *log_dets: np.sum(log_dets),
+            func_name='total_cov_mat_log_determinant', par_names=_log_det_names,
+            existing_behavior="replace")
 
         _cost_functions = [_fit._cost_function for _fit in self._fits]
         _cost_names = ['cost%s' % _i for _i in range(len(self._fits))]
@@ -277,21 +292,23 @@ class MultiFit(FitBase):
             func=lambda *p: _combine_cov_mats('y', *p),
             func_name='y_cov_mat', par_names=_y_cov_mat_names, add_children=False)
 
-        def total_cov_mat_inverse(x_cov_mat, derivatives, y_cov_mat):
+        def total_cov_mat_cholesky(x_cov_mat, derivatives, y_cov_mat):
             if self._min_x_error is not None:
                 _cov_mat = y_cov_mat + x_cov_mat * np.outer(derivatives, derivatives)
             else:
                 _cov_mat = y_cov_mat
-            return np.linalg.inv(_cov_mat)
+            return cholesky_decomposition(_cov_mat)
+        self._nexus.add_function(total_cov_mat_cholesky)
+        self._nexus.add_function(log_determinant, func_name="total_cov_mat_log_determinant",
+                                 par_names=["total_cov_mat_cholesky"], existing_behavior="replace")
 
-        self._nexus.add_function(total_cov_mat_inverse)
-        _shared_cost_function = SharedCostFunction()
+        self._shared_cost_function = SharedCostFunction()
         self._nexus.add_function(
-            func=_shared_cost_function, func_name=_shared_cost_function.name,
-            par_names=_shared_cost_function.arg_names
+            func=self._shared_cost_function, func_name=self._shared_cost_function.name,
+            par_names=self._shared_cost_function.arg_names
         )
-        _cost_functions.append(_shared_cost_function)
-        _cost_names.append(_shared_cost_function.name)
+        _cost_functions.append(self._shared_cost_function)
+        _cost_names.append(self._shared_cost_function.name)
         self._cost_function = MultiCostFunction(
             singular_cost_functions=_cost_functions, cost_function_names=_cost_names)
         self._nexus.add_function(
@@ -300,6 +317,7 @@ class MultiFit(FitBase):
             par_names=self._cost_function.arg_names,
             existing_behavior='replace'
         )
+        self._initialize_fitter()
 
     def _initialize_fitter(self):
         self._fitter = NexusFitter(
@@ -445,6 +463,58 @@ class MultiFit(FitBase):
     def data(self, new_data):
         raise NotImplementedError("Use data setters for individual fits instead.")
 
+    @property
+    def data_error(self):
+        raise NotImplementedError()
+
+    @property
+    def data_cov_mat(self):
+        raise NotImplementedError()
+
+    @property
+    def data_cov_mat_inverse(self):
+        raise NotImplementedError()
+
+    @property
+    def data_cor_mat(self):
+        raise NotImplementedError()
+
+    @property
+    def model_error(self):
+        raise NotImplementedError()
+
+    @property
+    def model_cov_mat(self):
+        raise NotImplementedError()
+
+    @property
+    def model_cov_mat_inverse(self):
+        raise NotImplementedError()
+
+    @property
+    def model_cor_mat(self):
+        raise NotImplementedError()
+
+    @property
+    def total_error(self):
+        return np.sqrt(np.diag(self.total_cov_mat))
+
+    @property
+    def total_cov_mat(self):
+        if self._shared_error_dicts:
+            _y_cov_mat = self._nexus.get("y_cov_mat").value
+            _x_cov_mat = self._nexus.get("x_cov_mat").value
+            _derivatives = self._nexus.get("derivatives").value
+            return _y_cov_mat + _x_cov_mat * np.outer(_derivatives, _derivatives)
+        else:
+            _total_cov_mat = np.zeros((self.data_size,) * 2)
+            _lower = 0
+            for _fit in self._fits:
+                _upper = _lower + _fit.data_size
+                _total_cov_mat[_lower:_upper, _lower:_upper] = _fit.total_cov_mat
+                _lower = _upper
+            return _total_cov_mat
+
     @property
     def data_container(self):
         """List of the data containers of the individual fits."""
@@ -523,16 +593,32 @@ class MultiFit(FitBase):
 
     @property
     def goodness_of_fit(self):
-        if isinstance(self._cost_function, MultiCostFunction):
-            _sum = 0.0
-            for _fit in self._fits:
-                _gof = _fit.goodness_of_fit
-                if _gof is None:
-                    return None
-                _sum += _gof
-            return _sum
-        else:
-            return super(MultiFit, self).goodness_of_fit
+        _gof_sum = 0.0
+        for _fit in self._fits:
+            if self._shared_error_nodes_initialized and _fit._cost_function.is_chi2:
+                continue
+            _gof = _fit.goodness_of_fit
+            if _gof is None:
+                return None
+            _gof_sum += _gof
+        if self._shared_error_nodes_initialized:
+            _gof_sum += self._shared_cost_function.goodness_of_fit(
+                *[self._nexus.get(_node_name).value
+                  for _node_name in self._shared_cost_function.arg_names])
+        return _gof_sum
+
+    @property
+    def chi2_probability(self):
+        """The chi2 probability for the current model values."""
+        _cost = self.cost_function_value
+        if self._shared_error_nodes_initialized:
+            _cost -= self._nexus.get("total_cov_mat_log_determinant").value
+        for _fit in self._fits:
+            _cost_func = _fit._cost_function
+            if _cost_func.add_determinant_cost and not (
+                    self._shared_error_nodes_initialized and _cost_func.is_chi2):
+                _cost -= _fit._nexus.get("total_cov_mat_log_determinant").value
+        return self._cost_function.chi2_probability(_cost, self.ndf)
 
     # -- public methods
 
@@ -573,6 +659,7 @@ class MultiFit(FitBase):
                 err_matrix=err_matrix, matrix_type=matrix_type, err_val=err_val, relative=relative,
                 fit_indices=fits
             )
+            _matrix_error.check_cov_mat_symmetry()
             return self._add_error_object(error_object=_matrix_error, reference=reference,
                                           name=name, axis=axis)
 
